<?php

   /**
    **  setup.php
    **  (c)2001 Nic Bernstein, for iTech, Inc.
    **  (c)2002 Nic Bernstein, for Onlight, llc.
    **
    **  setup for the ldifimport plugin
    **
    **/

function squirrelmail_plugin_init_ldifimport() {

  global $squirrelmail_plugin_hooks;

  $squirrelmail_plugin_hooks['optpage_register_block']['ldifimport']
      = 'squirrelmail_ldifimport_optpage_register_block';

}


function squirrelmail_ldifimport_optpage_register_block() {


  if (defined('SM_PATH'))
     include_once(SM_PATH . 'plugins/ldifimport/functions.php');
  else
     include_once('../plugins/ldifimport/functions.php');

  squirrelmail_ldifimport_optpage_register_block_do();

}


function ldifimport_version() {

   return '1.3';

}


?>
